<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Strumenti di file</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Strumenti di file</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translatorcomment>--exact match--
--file: Save_it.ts--
Sovrascrivere il file?
Il file esiste:
&apos;%1&apos;
Sovrascrivere?</translatorcomment>
        <translation>Sovrascrivere il file?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--exact match--
--file: Save_it.ts--
Il file &apos;%1&apos; esiste già. Vuoi sovrascriverlo?</translatorcomment>
        <translation>Il file &apos;%1&apos; esiste già. Vuoi sovrascriverlo?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation>Tutti i file</translation>
    </message>
</context>
</TS>
